@@ -163,16 +163,37 @@ def set_touch(ctx, key, policy, admin_pin, force):
     \b
     KEY     Key slot to set (sig, enc, aut or att).
     POLICY  Touch policy to set (on, off, fixed, cached or cached-fixed).
+
+    The touch policy is used to require user interaction for all
+    operations using the private key on the YubiKey. The touch policy is set
+    indivdually for each key slot. To see the current touch policy, run
+
+    \b
+        $ ykman openpgp info
+
+    Touch policies:
+
+    \b
+    Off (default)   No touch required
+    On              Touch required
+    Fixed           Touch required, can't be disabled without a full reset
+    Cached          Touch required, cached for 15s after use
+    Cached-Fixed    Touch required, cached for 15s after use, can't be disabled
+                    without a full reset
     """
     controller = ctx.obj['controller']
 
-    if admin_pin is None:
-        admin_pin = click.prompt('Enter admin PIN', hide_input=True, err=True)
-
     policy_name = policy.name.lower().replace('_', '-')
 
     if policy not in controller.supported_touch_policies:
-        ctx.fail('Touch policy {} not supported.'.format(policy_name))
+        ctx.fail('Touch policy {} not supported by this YubiKey.'
+                 .format(policy_name))
+
+    if key == KEY_SLOT.ATT and not controller.supports_attestation:
+        ctx.fail('Attestation is not supported by this YubiKey.')
+
+    if admin_pin is None:
+        admin_pin = click.prompt('Enter admin PIN', hide_input=True, err=True)
 
     if force or click.confirm(
         'Set touch policy of {} key to {}?'.format(
